/*
 * ################################################################
 *
 *                    Fractal GCM Management API
 *
 * Copyright (C) 2009 INRIA, University of
 *                    Nice-Sophia Antipolis, ActiveEon
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: proactive@ow2.org
 *
 * Authors: INRIA, University of Nice-Sophia Antipolis, ActiveEon.
 *
 * ################################################################
 */
package org.etsi.uri.gcm.api.control;

import java.net.URL;


/**
 * Component interface to control the migration of the component to which it belongs from the node where it has
 * been deployed to another one.
 *
 * @author INRIA, University of Nice-Sophia Antipolis, ActiveEon
 */
public interface MigrationController {

    /**
     * Migrates the component to which this interface belongs from the node where it has been deployed to the
     * one located at the URL represented by the given String.
     *
     * @param nodeURL String representing the URL of the node where to migrate the component to which this
     * interface belongs.
     * @throws MigrationException If the destination is not valid or when an error occurs during the migration.
     */
    public void migrateGCMComponentTo(String nodeURL) throws MigrationException;

    /**
     * Migrates the component to which this interface belongs from the node where it has been deployed to the
     * one located at the given URL.
     *
     * @param nodeURL {@link URL} of the node where to migrate the component to which this interface belongs.
     * @throws MigrationException If the destination is not valid or when an error occurs during the migration.
     */
    public void migrateGCMComponentTo(URL nodeURL) throws MigrationException;

    /**
     * Migrates the component to which this interface belongs from the node where it has been deployed to the
     * given one.
     *
     * @param node Reference on the node where to migrate the component to which this interface belongs.
     * @throws MigrationException If the destination is not valid or when an error occurs during the migration.
     */
    public void migrateGCMComponentTo(Object node) throws MigrationException;
}
